.. _halo-analysis:

Halo Analysis
=============

Using halo catalogs, understanding the different halo finding methods,
and using the halo mass function.

.. toctree::
   :maxdepth: 2

   halo_transition
   halo_catalogs
   halo_finders
   halo_mass_function
   halo_merger_tree
